# Perceptron Learning ALgorithms
Implement your perceptron learning algorithms with ease.


# Install
```
pip install Perceptron-pypi-gaurav98094
``

# Usage
```
from oneNeuron.perceptron import Perceptron
model = Perceptron()
model.fit(X,y,eta=0.01,epochs=10) 
```